@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,11 +33,12 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.documentai_v1.types import document
-from google.cloud.documentai_v1.types import document_processor_service
-from .transports.base import DocumentProcessorServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
+
+from google.cloud.documentai_v1.types import document, document_processor_service
+
 from .client import DocumentProcessorServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, DocumentProcessorServiceTransport
+from .transports.grpc_asyncio import DocumentProcessorServiceGrpcAsyncIOTransport
 
 
 class DocumentProcessorServiceAsyncClient:
@@ -237,9 +238,9 @@ class DocumentProcessorServiceAsyncClient:
 
             from google.cloud import documentai_v1
 
-            def sample_process_document():
+            async def sample_process_document():
                 # Create a client
-                client = documentai_v1.DocumentProcessorServiceClient()
+                client = documentai_v1.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 inline_document = documentai_v1.Document()
@@ -251,7 +252,7 @@ class DocumentProcessorServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.process_document(request=request)
+                response = await client.process_document(request=request)
 
                 # Handle the response
                 print(response)
@@ -321,7 +322,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -338,14 +344,13 @@ class DocumentProcessorServiceAsyncClient:
         r"""LRO endpoint to batch process many documents. The output is
         written to Cloud Storage as JSON in the [Document] format.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1
 
-            def sample_batch_process_documents():
+            async def sample_batch_process_documents():
                 # Create a client
-                client = documentai_v1.DocumentProcessorServiceClient()
+                client = documentai_v1.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = documentai_v1.BatchProcessRequest(
@@ -357,7 +362,7 @@ class DocumentProcessorServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -430,7 +435,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -455,14 +465,13 @@ class DocumentProcessorServiceAsyncClient:
         r"""Send a document for Human Review. The input document
         should be processed by the specified processor.
 
-
         .. code-block:: python
 
             from google.cloud import documentai_v1
 
-            def sample_review_document():
+            async def sample_review_document():
                 # Create a client
-                client = documentai_v1.DocumentProcessorServiceClient()
+                client = documentai_v1.DocumentProcessorServiceAsyncClient()
 
                 # Initialize request argument(s)
                 inline_document = documentai_v1.Document()
@@ -478,7 +487,7 @@ class DocumentProcessorServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -554,7 +563,12 @@ class DocumentProcessorServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
