@@ -13,14 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.rpc import status_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.documentai_v1.types import document as gcd_document
-from google.cloud.documentai_v1.types import document_io
-from google.cloud.documentai_v1.types import operation_metadata
-from google.protobuf import timestamp_pb2  # type: ignore
-from google.rpc import status_pb2  # type: ignore
-
+from google.cloud.documentai_v1.types import document_io, operation_metadata
 
 __protobuf__ = proto.module(
     package="google.cloud.documentai.v1",
@@ -65,13 +63,25 @@ class ProcessRequest(proto.Message):
     """
 
     inline_document = proto.Field(
-        proto.MESSAGE, number=4, oneof="source", message=gcd_document.Document,
+        proto.MESSAGE,
+        number=4,
+        oneof="source",
+        message=gcd_document.Document,
     )
     raw_document = proto.Field(
-        proto.MESSAGE, number=5, oneof="source", message=document_io.RawDocument,
+        proto.MESSAGE,
+        number=5,
+        oneof="source",
+        message=document_io.RawDocument,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    skip_human_review = proto.Field(
+        proto.BOOL,
+        number=3,
     )
-    name = proto.Field(proto.STRING, number=1,)
-    skip_human_review = proto.Field(proto.BOOL, number=3,)
 
 
 class HumanReviewStatus(proto.Message):
@@ -100,9 +110,19 @@ class HumanReviewStatus(proto.Message):
         IN_PROGRESS = 3
         ERROR = 4
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    state_message = proto.Field(proto.STRING, number=2,)
-    human_review_operation = proto.Field(proto.STRING, number=3,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    state_message = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    human_review_operation = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ProcessResponse(proto.Message):
@@ -117,9 +137,15 @@ class ProcessResponse(proto.Message):
             document.
     """
 
-    document = proto.Field(proto.MESSAGE, number=1, message=gcd_document.Document,)
+    document = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gcd_document.Document,
+    )
     human_review_status = proto.Field(
-        proto.MESSAGE, number=3, message="HumanReviewStatus",
+        proto.MESSAGE,
+        number=3,
+        message="HumanReviewStatus",
     )
 
 
@@ -138,19 +164,28 @@ class BatchProcessRequest(proto.Message):
             skipped for this request. Default to false.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     input_documents = proto.Field(
-        proto.MESSAGE, number=5, message=document_io.BatchDocumentsInputConfig,
+        proto.MESSAGE,
+        number=5,
+        message=document_io.BatchDocumentsInputConfig,
     )
     document_output_config = proto.Field(
-        proto.MESSAGE, number=6, message=document_io.DocumentOutputConfig,
+        proto.MESSAGE,
+        number=6,
+        message=document_io.DocumentOutputConfig,
+    )
+    skip_human_review = proto.Field(
+        proto.BOOL,
+        number=4,
     )
-    skip_human_review = proto.Field(proto.BOOL, number=4,)
 
 
 class BatchProcessResponse(proto.Message):
-    r"""Response message for batch process document method.
-    """
+    r"""Response message for batch process document method."""
 
 
 class BatchProcessMetadata(proto.Message):
@@ -204,19 +239,48 @@ class BatchProcessMetadata(proto.Message):
                 document.
         """
 
-        input_gcs_source = proto.Field(proto.STRING, number=1,)
-        status = proto.Field(proto.MESSAGE, number=2, message=status_pb2.Status,)
-        output_gcs_destination = proto.Field(proto.STRING, number=3,)
+        input_gcs_source = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        status = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message=status_pb2.Status,
+        )
+        output_gcs_destination = proto.Field(
+            proto.STRING,
+            number=3,
+        )
         human_review_status = proto.Field(
-            proto.MESSAGE, number=5, message="HumanReviewStatus",
+            proto.MESSAGE,
+            number=5,
+            message="HumanReviewStatus",
         )
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    state_message = proto.Field(proto.STRING, number=2,)
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    state_message = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
     individual_process_statuses = proto.RepeatedField(
-        proto.MESSAGE, number=5, message=IndividualProcessStatus,
+        proto.MESSAGE,
+        number=5,
+        message=IndividualProcessStatus,
     )
 
 
@@ -247,11 +311,24 @@ class ReviewDocumentRequest(proto.Message):
         URGENT = 1
 
     inline_document = proto.Field(
-        proto.MESSAGE, number=4, oneof="source", message=gcd_document.Document,
+        proto.MESSAGE,
+        number=4,
+        oneof="source",
+        message=gcd_document.Document,
+    )
+    human_review_config = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    enable_schema_validation = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
+    priority = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum=Priority,
     )
-    human_review_config = proto.Field(proto.STRING, number=1,)
-    enable_schema_validation = proto.Field(proto.BOOL, number=3,)
-    priority = proto.Field(proto.ENUM, number=5, enum=Priority,)
 
 
 class ReviewDocumentResponse(proto.Message):
@@ -263,7 +340,10 @@ class ReviewDocumentResponse(proto.Message):
             document.
     """
 
-    gcs_destination = proto.Field(proto.STRING, number=1,)
+    gcs_destination = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ReviewDocumentOperationMetadata(proto.Message):
@@ -279,9 +359,14 @@ class ReviewDocumentOperationMetadata(proto.Message):
     """
 
     common_metadata = proto.Field(
-        proto.MESSAGE, number=5, message=operation_metadata.CommonOperationMetadata,
+        proto.MESSAGE,
+        number=5,
+        message=operation_metadata.CommonOperationMetadata,
+    )
+    question_id = proto.Field(
+        proto.STRING,
+        number=6,
     )
-    question_id = proto.Field(proto.STRING, number=6,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
